@@ -560,13 +560,11 @@ void MainWindow::on_font8_editingFinished()
     ui->fontbuttonpressed->setStyleSheet(COLOR_STYLE.arg(f8, variables.value("DefaultBackgroundColor"), f8));
 }
 
-void MainWindow::on_pushButton_2_clicked()
+void MainWindow::on_actionChange_backgrounds_triggered()
 {
+    newWin = new backgrounds(this);
+    newWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+    newWin->setAttribute(Qt::WA_DeleteOnClose);
 
-        newWin = new backgrounds(this);
-        newWin->setAttribute(Qt::WA_Maemo5StackedWindow);
-        newWin->setAttribute(Qt::WA_DeleteOnClose);
-
-        newWin->show();
-
+    newWin->show();
 }
