@@ -53,7 +53,7 @@ private:
     bool openNewWin;
 
 private slots:
-    void on_pushButton_2_clicked();
+    void on_actionChange_backgrounds_triggered();
     void on_horizontalSlider_4_valueChanged(int value);
     void on_Opacity_editingFinished();
     void on_font8_editingFinished();
