@@ -123,11 +123,6 @@
         <source>Widget opacity %</source>
         <translation>Widgettien näkyvyys %</translation>
     </message>
-    <message>
-        <location filename="mainwindow.ui" line="0"/>
-        <source>Set backgrounds</source>
-        <translation>Muuta taustakuvia</translation>
-    </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
         <source>App shortcut size</source>
@@ -162,18 +157,23 @@
     <message>
         <location filename="mainwindow.ui" line="780"/>
         <source>Import fonts from MyDocs</source>
-        <translation>Tuo fontteja MyDocs -kansiosta</translation>
+        <translation>Tuo fontteja MyDocs:sta</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="783"/>
         <source>Import all font files from MyDocs</source>
-        <translation>Tuota kaikki fontit MyDocs -kansiosta</translation>
+        <translation>Tuo kaikki fontit MyDocs -kansiosta</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="788"/>
         <source>About</source>
         <translation>Tietoja</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Change backgrounds</source>
+        <translation>Vaihda taustoja</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="7"/>
         <source>Setting up the theme, please wait...</source>
