@@ -169,6 +169,11 @@
         <source>About</source>
         <translation>A propos</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Change backgrounds</source>
+        <translation>Changer le fond d&apos;écran</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="7"/>
         <source>Setting up the theme, please wait...</source>
@@ -198,7 +203,7 @@
     <message>
         <location filename="mainwindow.cpp" line="361"/>
         <source>Do you want to import fonts from MyDocs?</source>
-        <translation>Voulez-vous importer les fontes depuis &quot;MyDocs&quot;</translation>
+        <translation>Voulez-vous importer les fontes depuis &quot;MyDocs&quot;?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="362"/>
