@@ -172,6 +172,11 @@
         <source>About</source>
         <translation type="unfinished">About</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Change backgrounds</source>
+        <translation>Cambiar fondo</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="7"/>
         <source>Setting up the theme, please wait...</source>
