@@ -169,6 +169,11 @@
         <source>About</source>
         <translation>Om</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Change backgrounds</source>
+        <translation>Ändra bakgrund</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="7"/>
         <source>Setting up the theme, please wait...</source>
